@@ -1,6 +1,6 @@
 /* timers.h - header file for timers package
 **
-** Copyright  1995,1998,1999,2000 by Jef Poskanzer <jef@mail.acme.com>.
+** Copyright  1995,1998,1999,2000,2014 by Jef Poskanzer <jef@mail.acme.com>.
 ** All rights reserved.
 **
 ** Redistribution and use in source and binary forms, with or without
@@ -100,8 +100,8 @@ void tmr_cancel( Timer* timer );
 /* Clean up the timers package, freeing any unused storage. */
 void tmr_cleanup( void );
 
-/* Cancel all timers and free storage, usually in preparation for exitting. */
-void tmr_destroy( void );
+/* Cancel all timers and free storage, usually in preparation for exiting. */
+void tmr_term( void );
 
 /* Generate debugging statistics syslog message. */
 void tmr_logstats( long secs );
